@@ -7,7 +7,21 @@
 #' @seealso [actuar::Pareto]
 #'
 #' @examples
-#' dist_pareto(shape = c(10, 3, 2, 1), scale = rep(1, 4))
+#' dist <- dist_pareto(shape = c(10, 3, 2, 1), scale = rep(1, 4))
+#' dist
+#'
+#' @examplesIf requireNamespace("actuar", quietly = TRUE)
+#' mean(dist)
+#' variance(dist)
+#' support(dist)
+#' generate(dist, 10)
+#'
+#' density(dist, 2)
+#' density(dist, 2, log = TRUE)
+#'
+#' cdf(dist, 4)
+#'
+#' quantile(dist, 0.7)
 #'
 #' @name dist_pareto
 #' @export
@@ -23,11 +37,6 @@ dist_pareto <- function(shape, scale){
   new_dist(shape = shape, scale = scale, class = "dist_pareto")
 }
 
-#' @export
-print.dist_pareto <- function(x, ...){
-  cat(format(x, ...))
-}
-
 #' @export
 format.dist_pareto <- function(x, digits = 2, ...){
   sprintf(
@@ -73,6 +82,6 @@ mean.dist_pareto <- function(x, ...){
 }
 
 #' @export
-variance.dist_pareto <- function(x, ...){
+covariance.dist_pareto <- function(x, ...){
   actuar::mpareto(2, x[["shape"]], x[["scale"]]) - actuar::mpareto(1, x[["shape"]], x[["scale"]])^2
 }
