@@ -71,11 +71,6 @@ dist_weibull <- function(shape, scale){
   new_dist(shape = shape, scale = scale, class = "dist_weibull")
 }
 
-#' @export
-print.dist_weibull <- function(x, ...){
-  cat(format(x, ...))
-}
-
 #' @export
 format.dist_weibull <- function(x, digits = 2, ...){
   sprintf(
@@ -116,7 +111,7 @@ mean.dist_weibull <- function(x, ...){
 }
 
 #' @export
-variance.dist_weibull <- function(x, ...){
+covariance.dist_weibull <- function(x, ...){
   x[["scale"]]^2 * (gamma(1 + 2/x[["shape"]]) - gamma(1 + 1/x[["shape"]])^2)
 }
 
